[Libreoffice-commits] core.git: 2 commits - include/svtools include/svx sc/source sd/source svtools/source svx/source

Michael Meeks michael.meeks at suse.com
Thu Jun 6 14:25:11 PDT 2013


 include/svtools/sores.hxx                               |    1 -
 include/svx/svdoole2.hxx                                |    4 ++--
 sc/source/filter/excel/xiescher.cxx                     |    4 ++--
 sd/source/ui/view/drawview.cxx                          |    1 -
 svtools/source/dialogs/so3res.src                       |    4 ----
 svx/source/sdr/primitive2d/sdrolecontentprimitive2d.cxx |    3 +--
 svx/source/svdraw/svdoole2.cxx                          |    6 +++---
 7 files changed, 8 insertions(+), 15 deletions(-)

New commits:
commit 29c101fe68ad1794744ec576f9d020eb56bba4cd
Author: Michael Meeks <michael.meeks at suse.com>
Date:   Thu Jun 6 22:19:38 2013 +0100

    use a transparent graphic for the OLE2 image, and spell 'Empty' correctly.
    
    Change-Id: I94fbe74b6febede4819851dfa78690507b04f4f7

diff --git a/sc/source/filter/excel/xiescher.cxx b/sc/source/filter/excel/xiescher.cxx
index 87014d7..3c530f0 100644
--- a/sc/source/filter/excel/xiescher.cxx
+++ b/sc/source/filter/excel/xiescher.cxx
@@ -2903,8 +2903,8 @@ SdrObject* XclImpPictureObj::DoCreateSdrObj( XclImpDffConverter& rDffConv, const
     // avoid a 'blank' shape that can result from a failed control import
     if ( !xSdrObj && IsOcxControl() && maGraphic.GetType() == GRAPHIC_NONE )
     {
-        Graphic aReplacement( SdrOle2Obj::GetEmtyOLEReplacementBitmap() );
-        const_cast< XclImpPictureObj* >( this )->maGraphic = aReplacement;
+        const_cast< XclImpPictureObj* >( this )->maGraphic =
+                SdrOle2Obj::GetEmptyOLEReplacementGraphic();
     }
     // no OLE - create a plain picture from IMGDATA record data
     if( !xSdrObj && (maGraphic.GetType() != GRAPHIC_NONE) )
diff --git a/svx/source/sdr/primitive2d/sdrolecontentprimitive2d.cxx b/svx/source/sdr/primitive2d/sdrolecontentprimitive2d.cxx
index 7177957..cea71d5 100644
--- a/svx/source/sdr/primitive2d/sdrolecontentprimitive2d.cxx
+++ b/svx/source/sdr/primitive2d/sdrolecontentprimitive2d.cxx
@@ -55,8 +55,7 @@ namespace drawinglayer
             if(GRAPHIC_NONE == aGraphic.GetType())
             {
                 // no source, use fallback resource emty OLE graphic
-                const Bitmap aEmptyOLEBitmap(SdrOle2Obj::GetEmtyOLEReplacementBitmap());
-                aGraphic = Graphic(aEmptyOLEBitmap);
+                aGraphic = SdrOle2Obj::GetEmptyOLEReplacementGraphic();
                 bScaleContent = true;
             }
 
diff --git a/svx/source/svdraw/svdoole2.cxx b/svx/source/svdraw/svdoole2.cxx
index fcf27cc..af194c0 100644
--- a/svx/source/svdraw/svdoole2.cxx
+++ b/svx/source/svdraw/svdoole2.cxx
@@ -1338,7 +1338,7 @@ SdrObject* SdrOle2Obj::createSdrGrafObjReplacement(bool bAddText, bool /* bUseHC
 
         // bitmap fill
         pClone->SetMergedItem(XFillStyleItem(XFILL_BITMAP));
-        pClone->SetMergedItem(XFillBitmapItem(String(), Graphic(GetEmtyOLEReplacementBitmap())));
+        pClone->SetMergedItem(XFillBitmapItem(String(), GetEmptyOLEReplacementGraphic()));
         pClone->SetMergedItem(XFillBmpTileItem(false));
         pClone->SetMergedItem(XFillBmpStretchItem(false));
 
@@ -2208,9 +2208,9 @@ sal_Bool SdrOle2Obj::AddOwnLightClient()
 
 //////////////////////////////////////////////////////////////////////////////
 
-Bitmap SdrOle2Obj::GetEmtyOLEReplacementBitmap()
+Graphic SdrOle2Obj::GetEmptyOLEReplacementGraphic()
 {
-    return Bitmap(ResId(BMP_SVXOLEOBJ, *ImpGetResMgr()));
+    return Graphic(BitmapEx(ResId(BMP_SVXOLEOBJ, *ImpGetResMgr())));
 }
 
 //////////////////////////////////////////////////////////////////////////////
commit 3fe227a65de7bd4aae803dcff6802824c624bd09
Author: Michael Meeks <michael.meeks at suse.com>
Date:   Thu Jun 6 22:08:55 2013 +0100

    remove unused BMP_OLEOBJ image and define.
    
    Change-Id: I809cca8dab246c7b528309fd74fb73a9d0bd418f

diff --git a/include/svtools/sores.hxx b/include/svtools/sores.hxx
index 4264f21..71e6359 100644
--- a/include/svtools/sores.hxx
+++ b/include/svtools/sores.hxx
@@ -25,7 +25,6 @@
 #define STR_UNKNOWN_SOURCE                      32027
 
 #define BMP_PLUGIN                      32000
-#define BMP_OLEOBJ                      32001
 #define MB_PLUGIN                       32000
 #define MI_PLUGIN                       32000
 #define MI_PLUGIN_DEACTIVATE            1
diff --git a/sd/source/ui/view/drawview.cxx b/sd/source/ui/view/drawview.cxx
index 6b80bc5..27c5ece 100644
--- a/sd/source/ui/view/drawview.cxx
+++ b/sd/source/ui/view/drawview.cxx
@@ -41,7 +41,6 @@
 #include "stlsheet.hxx"
 
 #include <svx/svdoutl.hxx>
-#undef BMP_OLEOBJ
 #include <svx/svdstr.hrc>
 #include <svx/dialmgr.hxx>
 
diff --git a/svtools/source/dialogs/so3res.src b/svtools/source/dialogs/so3res.src
index a62ef13..82bb505 100644
--- a/svtools/source/dialogs/so3res.src
+++ b/svtools/source/dialogs/so3res.src
@@ -189,10 +189,6 @@ Bitmap BMP_PLUGIN
 {
     File = "plugin.png" ;
 };
-Bitmap BMP_OLEOBJ
-{
-    File = "oleobj.png" ;
-};
 Menu MB_PLUGIN
 {
     ItemList =


More information about the Libreoffice-commits mailing list
diff --git a/include/svx/svdoole2.hxx b/include/svx/svdoole2.hxx
index ee5542c..92b4ad5 100644
--- a/include/svx/svdoole2.hxx
+++ b/include/svx/svdoole2.hxx
@@ -181,8 +181,8 @@ public:
     sal_Bool CalculateNewScaling( Fraction& aScaleWidth, Fraction& aScaleHeight, Size& aObjAreaSize );
     sal_Bool AddOwnLightClient();
 
-    // handy to get the empty replacement bitmap without accessing all the old stuff
-    static Bitmap GetEmtyOLEReplacementBitmap();
+    // handy to get the empty replacement graphic without accessing all the old stuff
+    static Graphic GetEmptyOLEReplacementGraphic();
 
     void SetWindow(const com::sun::star::uno::Reference < com::sun::star::awt::XWindow >& _xWindow);
 